@@ -3,6 +3,7 @@ from __future__ import annotations
 from .base import MCPAgent
 from .claude import ClaudeAgent
 from .gemini import GeminiAgent
+from .gemini_cua import GeminiCUAAgent
 from .openai import OpenAIAgent
 from .openai_chat import OpenAIChatAgent
 from .operator import OperatorAgent
@@ -10,6 +11,7 @@ from .operator import OperatorAgent
 __all__ = [
     "ClaudeAgent",
     "GeminiAgent",
+    "GeminiCUAAgent",
     "MCPAgent",
     "OpenAIAgent",
     "OpenAIChatAgent",
